Subject: [bug#70855] [PATCH 80/92] gnu: python-pytest-trio: Move to pyproject-build-system.

From: Nicolas Graves <[email-masked]>
Date: Fri, 10 May 2024 00:54:15 +0200

* gnu/packages/python-check.scm (python-pytest-trio):
  [build-system]: Move to pyproject-build-system.
  [arguments]: Move from <#:phases> to <#test-flags>.

Change-Id: I7653110fc299d0757f7e01c2c1c29d599cb206bf
---
 gnu/packages/python-check.scm | 25 ++++++++++---------------
 1 file changed, 10 insertions(+), 15 deletions(-)

diff --git a/gnu/packages/python-check.scm b/gnu/packages/python-check.scm
index ccda2042fb6..46c8b3414e4 100644
--- a/gnu/packages/python-check.scm
+++ b/gnu/packages/python-check.scm
@@ -1186,22 +1186,17 @@ (define-public python-pytest-trio
        (uri (pypi-uri "pytest-trio" version))
        (sha256
         (base32 "0c8cqf9by2884riksrqymqfp2g1d2d798a2zalcw9hmf34c786y0"))))
-    (build-system python-build-system)
+    (build-system pyproject-build-system)
     (arguments
-     `(#:phases
-       (modify-phases %standard-phases
-         (replace 'check
-           (lambda* (#:key tests? inputs outputs #:allow-other-keys)
-             (when tests?
-               (add-installed-pythonpath inputs outputs)
-               (invoke "pytest" "-W" "error" "-ra" "-v" "--pyargs"
-                       "pytest_trio" "--verbose" "--cov" "-k"
-                       (string-append
-                         ;; Needs network
-                         "not test_async_yield_fixture_with_nursery"
-                         " and not test_try"
-                         ;; No keyboard interrupt in our build environment.
-                         " and not test_actual_test"))))))))
+     (list
+      #:test-flags '(list "-W" "error" "-ra" "-v" "--pyargs"
+                          "pytest_trio" "--verbose" "--cov" "-k"
+                          (string-append
+                           ;; Needs network
+                           "not test_async_yield_fixture_with_nursery"
+                           " and not test_try"
+                           ;; No keyboard interrupt in our build environment.
+                           " and not test_actual_test"))))
     (native-inputs
      (list python-hypothesis python-pytest python-pytest-cov))
     (propagated-inputs
-- 
2.41.0